@@ -13,6 +13,10 @@ from sklearn.datasets import load_digits
 from sklearn.cross_validation import train_test_split
 from sklearn.ensemble import RandomForestClassifier
 from sklearn.tree import DecisionTreeClassifier
+from sklearn.svm import SVC
+from sklearn.linear_model import LogisticRegression
+from sklearn.neighbors import KNeighborsClassifier
+
 
 # Set up the iris data set for testing
 mnist_data = load_digits()
@@ -93,31 +97,30 @@ def test_combine_dfs():
 
     assert tpot_obj._combine_dfs(df1, df2).equals(combined_df)
 
-def test_subset_df():
+def test_static_models():
+    '''
+        Ensure that the TPOT static classifiers outputs the same as the sklearn output
+    '''
+
+
     tpot_obj = TPOT()
+    models = [(tpot_obj.decision_tree, DecisionTreeClassifier, {'max_features':0, 'max_depth':0}, {'max_features':'auto', 'max_depth':None}),
+            (tpot_obj.svc, SVC , {'C':0.0001}, {'C':0.0001}),
+            (tpot_obj.random_forest, RandomForestClassifier,{'n_estimators':100, 'max_features':0}, {'n_estimators':100, 'max_features':'auto', 'n_jobs':-1}),
+                (tpot_obj.logistic_regression, LogisticRegression, {'C':0.0001}, {'C':0.0001}), 
+                (tpot_obj.knnc, KNeighborsClassifier, {'n_neighbors':100}, {'n_neighbors':100})]
+    for model, sklearn_model, model_params, sklearn_params in models:
+        
+        result = model(training_testing_data, **model_params)
+        try:
+            sklearn_model_obj = sklearn_model(random_state=42, **sklearn_params)
+            sklearn_model_obj.fit(training_features, training_classes)
+        except TypeError:
+            sklearn_model_obj = sklearn_model(**sklearn_params)
+            sklearn_model_obj.fit(training_features, training_classes)
 
-    test_df = pd.DataFrame({'00000': range(10),
-                            '00001': range(10),
-                            '00002': range(10),
-                            '00003': range(10),
-                            '00004': range(10),
-                            '00005': range(10),
-                            '00006': range(10),
-                            '00007': range(10),
-                            '00008': range(10),
-                            '00009': range(10),
-                            'guess': range(10),
-                            'class': range(10),
-                            'group': range(10)})
+        result = result[result['group'] == 'testing']
 
-    assert np.array_equal(tpot_obj._subset_df(test_df, 3, 8).columns.values,
-                          ['00003', '00004', '00005', '00006', '00007', 'guess', 'class', 'group'])
+        assert np.array_equal(result['guess'].values, sklearn_model_obj.predict(testing_features)), "Model {} failed".format(str(model))
 
-def test_df_feature_selection():
-    tpot_obj = TPOT()
 
-    top_10_feature_pairs = ['00002', '00013', '00020', '00021', '00026', '00042',
-                            '00043', '00058', '00061', 'class', 'group', 'guess']
-
-    assert np.array_equal(tpot_obj._dt_feature_selection(training_testing_data, 10).columns.values,
-                          top_10_feature_pairs)
